A supporting function that return the local polynomial regression quantile. This estimates the quantile and its derivative at the point x.0
lprq0(x, y, h, tau = 0.5, x0)covariate sequence;
response sequence;
bandwidth(scalar);
- left-tail probability
point at which the quantile is estimated
x0 a scalar
fv quantile est; dv - quantile derivative est